calculate_daily_spawn_energy: Calculate reproductive energy loss for the day (Low-level)

View source: R/12-simulation-engine.R

calculate_daily_spawn_energyR Documentation

Calculate reproductive energy loss for the day (Low-level)

Description

Calculates energy lost to reproduction on a given day based on reproduction data and current fish condition.

Usage

calculate_daily_spawn_energy(
  day,
  current_weight,
  predator_ed,
  reproduction_data = NULL
)

Arguments

day

Current simulation day

current_weight

Current fish weight (g)

predator_ed

Current predator energy density (J/g)

reproduction_data

Vector with reproduction fractions by day

Value

Spawning energy loss (J)


fb4package documentation built on May 8, 2026, 1:07 a.m.