calculate_final_weight_fb4: Calculate final weight using FB4 equations (Mid-level)

View source: R/04-predator-energy-density.R

calculate_final_weight_fb4R Documentation

Calculate final weight using FB4 equations (Mid-level)

Description

Main function for calculating final weight from energy balance

Usage

calculate_final_weight_fb4(
  initial_weight,
  net_energy,
  spawn_energy = 0,
  processed_predator_params,
  day = 1
)

Arguments

initial_weight

Initial weight (g)

net_energy

Net available energy (J)

spawn_energy

Energy lost to reproduction (J)

processed_predator_params

Processed predator parameters

day

Current day

Value

A named list with three elements:

final_weight

Numeric scalar. Fish weight (g) at end of day, after accounting for net energy and reproductive losses. Minimum value is 0.01 g.

final_energy_density

Numeric scalar. Energy density (J/g) corresponding to final_weight.

weight_change

Numeric scalar. Change in weight (g) during the day (final_weight - initial_weight); negative values indicate weight loss.

Examples

# PREDEDEQ 3: power function, positive net energy (weight gain)
params <- list(PREDEDEQ = 3, Alpha1 = 4800, Beta1 = 0.1)
calculate_final_weight_fb4(initial_weight = 100, net_energy = 500,
                           processed_predator_params = params)

fb4package documentation built on May 8, 2026, 1:07 a.m.