View source: R/04-predator-energy-density.R
| calculate_predator_energy_density | R Documentation |
Main energy density calculation function called from simulation loop
calculate_predator_energy_density(weight, day = 1, processed_predator_params)
weight |
Fish weight (g) |
day |
Simulation day (for equation 1) |
processed_predator_params |
List with processed predator parameters |
A numeric scalar giving the predator energy density in J per g fish,
calculated according to processed_predator_params$PREDEDEQ
(1 = interpolated daily data; 2 = piecewise linear by weight;
3 = power function of weight).
# PREDEDEQ 3: power function of weight
params <- list(PREDEDEQ = 3, Alpha1 = 4800, Beta1 = 0.1)
calculate_predator_energy_density(weight = 100, processed_predator_params = params)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.