Skip to contents

Functions implementing four egestion models (EGEQ 1–4) and four excretion models (EXEQ 1–4). These represent losses of consumed energy as feces (F) and nitrogenous wastes (U) respectively.

Egestion models:

EGEQ 1 — constant fraction: \(F = FA \cdot C\)

EGEQ 2 — Elliott (1976), temperature- and feeding-dependent: \(F = FA \cdot T^{FB} \cdot e^{FG \cdot p} \cdot C\)

EGEQ 3 — Stewart et al. (1983), includes indigestible fraction: modified form of EGEQ 2 accounting for indigestible prey material.

EGEQ 4 — Elliott (1976), temperature-dependent only: \(F = FA \cdot T^{FB} \cdot C\)

Excretion models:

EXEQ 1 — constant fraction of assimilated energy: \(U = UA \cdot (C - F)\)

EXEQ 2–3 — Elliott (1976), temperature- and feeding-dependent: \(U = UA \cdot T^{UB} \cdot e^{UG \cdot p} \cdot (C - F)\)

EXEQ 4 — temperature-dependent only.

References

Elliott, J.M. (1976). Energy losses in the waste products of brown trout (Salmo trutta L.). Journal of Animal Ecology, 45(2), 561–580.

Stewart, D.J., Weininger, D., Rottiers, D.V. and Edsall, T.A. (1983). An energetics model for lake trout, Salvelinus namaycush: application to the Lake Michigan population. Canadian Journal of Fisheries and Aquatic Sciences, 40(6), 681–698.

Hanson, P.C., Johnson, T.B., Schindler, D.E. and Kitchell, J.F. (1997). Fish Bioenergetics 3.0. University of Wisconsin Sea Grant Institute, Madison, WI.

Deslauriers, D., Chipps, S.R., Breck, J.E., Rice, J.A. and Madenjian, C.P. (2017). Fish Bioenergetics 4.0: An R-based modeling application. Fisheries, 42(11), 586–596. doi:10.1080/03632415.2017.1377558