View source: R/14.2.5-strategy-mle.R
| mle_estimate_p_value_lognormal | R Documentation |
Estimates p_value and uncertainty using observed final weights with a frequentist likelihood approach assuming log-normal weight distribution.
mle_estimate_p_value_lognormal(
observed_weights,
simulation_function,
estimate_sigma = TRUE,
fixed_sigma = 0.1
)
observed_weights |
Vector of observed final weights |
simulation_function |
Function that runs simulation and returns weight |
estimate_sigma |
Whether to estimate sigma or use fixed value |
fixed_sigma |
Fixed sigma value (if estimate_sigma = FALSE) |
List with MLE results
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.