Nutrient Regeneration Functions for FB4 Model
Source:R/07-nutrient-regeneration.R
nutrient-regeneration.RdExperimental functions for computing daily nitrogen (N) and phosphorus (P) fluxes in fish using a mass-balance approach consistent with ecological stoichiometry theory. For each element the daily budget is:
$$\text{Consumed} = \text{Assimilated} + \text{Egested}$$ $$\text{Assimilated} = \text{Growth} + \text{Excreted}$$
Assimilation efficiencies for N and P are species- and prey-specific and can differ from those used for energy.
Value
No return value; this page documents the nutrient regeneration functions module. See individual function documentation for return values.
References
Sterner, R.W. and Elser, J.J. (2002). Ecological Stoichiometry: The Biology of Elements from Molecules to the Biosphere. Princeton University Press, Princeton, NJ.
Deslauriers, D., Chipps, S.R., Breck, J.E., Rice, J.A. and Madenjian, C.P. (2017). Fish Bioenergetics 4.0: An R-based modeling application. Fisheries, 42(11), 586–596. doi:10.1080/03632415.2017.1377558