| plot.Bioenergetic | R Documentation |
Plotting method for Bioenergetic objects to validate setup before simulation.
## S3 method for class 'Bioenergetic'
plot(x, type = "dashboard", save_plot = NULL, ...)
x |
Object of class Bioenergetic |
type |
Type of plot: "dashboard", "temperature", "diet", "energy" |
save_plot |
Optional path to save plot |
... |
Additional arguments |
Invisibly returns the input object x, called for its
plotting side-effect.
data(fish4_parameters)
sp <- fish4_parameters[["Oncorhynchus tshawytscha"]]$life_stages$adult
info <- fish4_parameters[["Oncorhynchus tshawytscha"]]$species_info
bio <- Bioenergetic(
species_params = sp,
species_info = info,
environmental_data = list(
temperature = data.frame(Day = 1:30, Temperature = rep(12, 30))
),
diet_data = list(
proportions = data.frame(Day = 1:30, Prey1 = 1.0),
energies = data.frame(Day = 1:30, Prey1 = 5000),
prey_names = "Prey1"
),
simulation_settings = list(initial_weight = 100, duration = 30)
)
bio$species_params$predator$ED_ini <- 5000
bio$species_params$predator$ED_end <- 5500
plot(bio)
plot(bio, type = "temperature")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.