View source: R/02-respiration.R
| respiration_temp_eq2 | R Documentation |
Implements temperature equation 2 (Kitchell et al. 1977). With user notifications about edge cases and fallback values.
respiration_temp_eq2(temperature, RTM, RTO, RX, warn = TRUE)
temperature |
Water temperature (deg C) |
RTM |
Maximum (lethal) temperature |
RTO |
Optimum temperature for respiration |
RX |
Calculated parameter |
warn |
Logical, whether to issue warnings about calculations, default TRUE |
This function calculates temperature effects on respiration using: V = (RTM - temperature) / (RTM - RTO) ft = V^RX × exp(RX × (1 - V))
Special cases: - When temperature >= RTM: returns 0.000001 (lethal temperature) - When ft < 0: returns 0.000001 (mathematical protection)
Note: Negative values can occur with certain RX parameters, hence the minimum bound.
Temperature factor
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.