sdr_pull_se: Pull a scalar standard error from an sdreport summary

View source: R/14.0-tmb-shared.R

sdr_pull_seR Documentation

Pull a scalar standard error from an sdreport summary

Description

Pull a scalar standard error from an sdreport summary

Usage

sdr_pull_se(sdr_summary, name)

Arguments

sdr_summary

Matrix returned by summary(TMB::sdreport(obj))

name

Row name to look up

Value

Numeric scalar SE, or NA_real_ if not found


fb4package documentation built on May 8, 2026, 1:07 a.m.