Set Environmental Data for Bioenergetic Objects
Source:R/13.0-bioenergetic-classes.R
set_environment.RdUpdates the environmental data component of a Bioenergetic object with new temperature information.
R/13.0-bioenergetic-classes.R
set_environment.RdUpdates the environmental data component of a Bioenergetic object with new temperature information.