View source: R/13.0-bioenergetic-classes.R
| set_parameter_value | R Documentation |
Sets a specific parameter value in species parameter lists, automatically finding the correct category.
set_parameter_value(params, param, value)
params |
Species parameters list |
param |
Parameter name to set |
value |
New parameter value |
The params list with params[[category]][[param]]
replaced by value, where category is the first category
in which param is found. Throws an error if param is not
found in any category.
sp <- list(consumption = list(CA = 0.303, CB = -0.275))
updated <- set_parameter_value(sp, "CA", 0.350)
updated$consumption$CA
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.