View source: R/04-predator-energy-density.R
| solve_weight_iterative | R Documentation |
General safe method for solving final weight when analytical solutions fail Used as fallback for complex cases
solve_weight_iterative(
target_energy,
processed_predator_params,
day = 1,
initial_guess = 1000
)
target_energy |
Target body energy |
processed_predator_params |
Processed predator parameters |
day |
Current day |
initial_guess |
Initial weight estimate |
Final weight
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.