Learn R Programming

fb4package (version 2.0.0)

strategy-binary-search: Binary Search Strategy for FB4 Model

Description

Implements the "binary_search" FB4 fitting strategy, which finds the proportion of maximum consumption (p-value) that minimises the difference between a simulated metric and a user-supplied target. Supported fitting targets are "Weight" (final weight in g) and "Consumption" (total consumption in g). The strategy is instantiated by create_binary_search_strategy; the search algorithm itself is in binary_search_p_value, coordinated by fit_fb4_binary_search.

Arguments

Value

No return value; this page documents the binary search strategy functions. See individual function documentation for return values.

References

Hanson, P.C., Johnson, T.B., Schindler, D.E. and Kitchell, J.F. (1997). Fish Bioenergetics 3.0. University of Wisconsin Sea Grant Institute, Madison, WI.

Deslauriers, D., Chipps, S.R., Breck, J.E., Rice, J.A. and Madenjian, C.P. (2017). Fish Bioenergetics 4.0: An R-based modeling application. Fisheries, 42(11), 586–596. tools:::Rd_expr_doi("10.1080/03632415.2017.1377558")