View source: R/11.3-data-validators.R
| validate_complete_simulation_data | R Documentation |
Validates the complete processed simulation data structure before running.
validate_complete_simulation_data(simulation_data)
simulation_data |
Complete processed simulation data |
Invisibly returns TRUE if validation passes. Throws an error
with a descriptive message if the simulation data structure is invalid.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.