validate_data_consistency: Validate data consistency between components

View source: R/11.3-data-validators.R

validate_data_consistencyR Documentation

Validate data consistency between components

Description

Checks cross-component consistency within processed simulation data.

Usage

validate_data_consistency(simulation_data, n_prey_temporal)

Arguments

simulation_data

Complete simulation data

n_prey_temporal

Number of prey species in temporal data

Value

Invisibly returns TRUE if all cross-component consistency checks pass. Throws an error with a descriptive message when optional contaminant or nutrient concentration matrices are present but their number of columns does not match the number of prey species (n_prey_temporal).


fb4package documentation built on May 8, 2026, 1:07 a.m.