Learn R Programming

fb4package (version 2.0.0)

validate_nutrient_concentrations: Validate nutrient concentrations

Description

Validate nutrient concentrations

Usage

validate_nutrient_concentrations(
  nutrient_concentrations,
  organism_type = "fish"
)

Value

A named list with three elements: valid (logical),

errors (character vector), and warnings (character vector). warnings are issued when N or P concentrations fall outside the typical range for the specified organism_type or when the N:P mass ratio is outside 2--20.

Arguments

nutrient_concentrations

List with N and P concentrations

organism_type

Organism type for validation

Examples

Run this code
validate_nutrient_concentrations(list(
  nitrogen   = 0.030,
  phosphorus = 0.004
))$valid

Run the code above in your browser using DataLab