Learn R Programming

fb4package (version 2.0.0)

accumulate_validations: Accumulate multiple validation results

Description

Combines multiple validation results into a single result, aggregating errors, warnings, and info messages.

Usage

accumulate_validations(..., level = "combined")

Value

An object of class fb4_validation (see

validation_result) representing the combined state of all inputs. valid is TRUE only if all supplied results are valid. errors and warnings are the concatenation of those fields across all inputs.

Arguments

...

Validation result objects to combine

level

Overall validation level for the combined result

Examples

Run this code
r1 <- validation_result(valid = TRUE)
r2 <- validation_result(valid = FALSE, errors = "value out of range")
accumulate_validations(r1, r2)

Run the code above in your browser using DataLab