Skip to contents

Analyzes how growth rates respond to different temperature and feeding level combinations. Uses p-values (proportion of maximum consumption capacity) to simulate feeding scenarios from survival levels (p ~0.2) to maximum capacity (p = 1.0). Parallelized for efficiency.

Usage

analyze_growth_temperature_sensitivity(
  bio_obj,
  temperatures = seq(8, 18, by = 2),
  p_values = seq(0.3, 1, by = 0.1),
  simulation_days = 365,
  oxycal = 13560,
  parallel = FALSE,
  n_cores = NULL,
  verbose = TRUE
)

Arguments

bio_obj

Bioenergetic object containing species parameters and environmental data

temperatures

Vector of temperatures to test in °C (default: 8-18°C by 2°C steps)

p_values

Vector of p-values representing feeding levels as proportion of Cmax (default: 0.3-1.0)

simulation_days

Number of days to simulate (default: 365)

oxycal

Oxycalorific coefficient in J/g O2 (default: 13560)

parallel

Use parallel processing (default: FALSE)

n_cores

Number of cores for parallel processing (default: detectCores() - 1)

verbose

Show progress information (default: TRUE)

Examples

if (FALSE) { # \dontrun{
# Basic sensitivity analysis
results <- analyze_growth_temperature_sensitivity(bio_obj)

# Custom parameter ranges for cold water species
results <- analyze_growth_temperature_sensitivity(
  bio_obj,
  temperatures = seq(4, 14, by = 2),
  p_values = seq(0.2, 0.9, by = 0.1)
)
} # }