View source: R/12-simulation-engine.R
| calculate_daily_spawn_energy | R Documentation |
Calculates energy lost to reproduction on a given day based on reproduction data and current fish condition.
calculate_daily_spawn_energy(
day,
current_weight,
predator_ed,
reproduction_data = NULL
)
day |
Current simulation day |
current_weight |
Current fish weight (g) |
predator_ed |
Current predator energy density (J/g) |
reproduction_data |
Vector with reproduction fractions by day |
Spawning energy loss (J)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.