Calculates energy lost to reproduction on a given day based on reproduction data and current fish condition.
calculate_daily_spawn_energy(
day,
current_weight,
predator_ed,
reproduction_data = NULL
)Spawning energy loss (J)
Current simulation day
Current fish weight (g)
Current predator energy density (J/g)
Vector with reproduction fractions by day