Calculate nutrient retention efficiencies
Source:R/15.2-analysis-nutritional.R
calculate_nutrient_efficiencies.RdCalculates assimilation and retention efficiencies for nitrogen and phosphorus. These metrics are important for understanding nutrient use efficiency.
Value
A named list with four elements:
- nitrogen
Named list with four numeric scalars:
assimilation_efficiency(fraction consumed that is assimilated),retention_efficiency(fraction consumed retained in growth),excretion_rate(fraction consumed lost via excretion), andgrowth_efficiency(fraction assimilated retained in growth).- phosphorus
Same structure as
nitrogenbut for phosphorus.- relative_n_retention
Numeric. Ratio of nitrogen to phosphorus retention efficiency;
NAwhen phosphorus retention is zero.- relative_n_excretion
Numeric. Ratio of nitrogen to phosphorus excretion rate;
NAwhen phosphorus excretion rate is zero.
Examples
nitrogen <- list(consumed = 10, assimilated = 8, growth = 3, excretion = 5,
egestion = 2, assimilation_efficiency = 0.8)
phosphorus <- list(consumed = 1.5, assimilated = 1.1, growth = 0.5,
excretion = 0.6, egestion = 0.4, assimilation_efficiency = 0.73)
calculate_nutrient_efficiencies(nitrogen, phosphorus)
#> $nitrogen
#> $nitrogen$assimilation_efficiency
#> [1] 0.8
#>
#> $nitrogen$retention_efficiency
#> [1] 0.3
#>
#> $nitrogen$excretion_rate
#> [1] 0.5
#>
#> $nitrogen$growth_efficiency
#> [1] 0.375
#>
#>
#> $phosphorus
#> $phosphorus$assimilation_efficiency
#> [1] 0.73
#>
#> $phosphorus$retention_efficiency
#> [1] 0.3333333
#>
#> $phosphorus$excretion_rate
#> [1] 0.4
#>
#> $phosphorus$growth_efficiency
#> [1] 0.4545455
#>
#>
#> $relative_n_retention
#> [1] 0.9
#>
#> $relative_n_excretion
#> [1] 1.25
#>