View source: R/15.2-analysis-nutritional.R
| calculate_nutrient_efficiencies | R Documentation |
Calculates assimilation and retention efficiencies for nitrogen and phosphorus. These metrics are important for understanding nutrient use efficiency.
calculate_nutrient_efficiencies(nitrogen_fluxes, phosphorus_fluxes)
nitrogen_fluxes |
List result from calculate_nutrient_balance (nitrogen component) |
phosphorus_fluxes |
List result from calculate_nutrient_balance (phosphorus component) |
A named list with four elements:
Named list with four numeric scalars:
assimilation_efficiency (fraction consumed that is assimilated),
retention_efficiency (fraction consumed retained in growth),
excretion_rate (fraction consumed lost via excretion), and
growth_efficiency (fraction assimilated retained in growth).
Same structure as nitrogen but for
phosphorus.
Numeric. Ratio of nitrogen to phosphorus
retention efficiency; NA when phosphorus retention is zero.
Numeric. Ratio of nitrogen to phosphorus
excretion rate; NA when phosphorus excretion rate is zero.
nitrogen <- list(consumed = 10, assimilated = 8, growth = 3, excretion = 5,
egestion = 2, assimilation_efficiency = 0.8)
phosphorus <- list(consumed = 1.5, assimilated = 1.1, growth = 0.5,
excretion = 0.6, egestion = 0.4, assimilation_efficiency = 0.73)
calculate_nutrient_efficiencies(nitrogen, phosphorus)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.