Skip to contents

Functions implementing the four consumption temperature-dependence equations (CEQ 1–4) and the allometric maximum-consumption function used in FB4. Consumption is modelled as:

$$C = C_{\max} \cdot p \cdot F(T), \quad C_{\max} = CA \cdot W^{CB}$$

where \(p\) is the proportion of maximum consumption (P-value), \(F(T)\) is a temperature-dependence function, \(W\) is body mass (g), and \(CA\), \(CB\) are species-specific intercept and slope coefficients.

CEQ 1 — simple Q10 exponential: \(F(T) = e^{CQ \cdot T}\)

CEQ 2 — Kitchell et al. (1977): \(F(T) = V^{CX} \cdot e^{CX(1-V)}\), where \(V = (CTM - T)/(CTM - CTO)\)

CEQ 3 — Thornton and Lessem (1978): two-part sigmoid using \(CQ\), \(CTO\), \(CTL\), \(CTM\), \(CK1\), \(CK4\)

CEQ 4 — polynomial: \(F(T) = e^{CQ \cdot T + CK1 \cdot T^2 + CK4 \cdot T^3}\)

References

Kitchell, J.F., Stewart, D.J. and Weininger, D. (1977). Applications of a bioenergetics model to yellow perch and walleye. Journal of the Fisheries Research Board of Canada, 34(10), 1922–1935.

Thornton, K.W. and Lessem, A.S. (1978). A temperature algorithm for modifying biological rates. Transactions of the American Fisheries Society, 107(2), 284–287.

Hartman, K.J. and Hayward, R.S. (2007). Bioenergetics. In C.S. Guy and M.L. Brown (eds.), Analysis and Interpretation of Freshwater Fisheries Data. American Fisheries Society, Bethesda, MD.

Deslauriers, D., Chipps, S.R., Breck, J.E., Rice, J.A. and Madenjian, C.P. (2017). Fish Bioenergetics 4.0: An R-based modeling application. Fisheries, 42(11), 586–596. doi:10.1080/03632415.2017.1377558