Coordinates the bootstrap fitting process: runs the resampling loop via
bootstrap_p_values, computes summary statistics and confidence
intervals, and runs a final detailed simulation with the mean p_value.
fit_fb4_bootstrap(
final_weights,
processed_simulation_data,
n_bootstrap = 1000,
oxycal = 13560,
confidence_level = 0.95,
sample_size = NULL,
compute_percentiles = TRUE,
parallel = FALSE,
n_cores = NULL,
upper_p = 1,
verbose = FALSE,
store_predicted_weights = TRUE
)List with bootstrap fitting results including consumption and predicted weights
Vector of final observed weights
Complete processed simulation data (contains initial_weight)
Number of bootstrap iterations, default 1000
Oxycalorific coefficient (J/g O2), default 13560
Confidence level for intervals, default 0.95
Sample size for each bootstrap iteration (NULL = same as original)
Whether to compute additional percentiles, default TRUE
Whether to use parallel processing, default FALSE
Number of cores for parallel processing (NULL = auto-detect)
Whether to show progress messages, default FALSE
Whether to store predicted final weights, default TRUE