Experimental functions for computing daily nitrogen (N) and phosphorus (P) fluxes in fish using a mass-balance approach consistent with ecological stoichiometry theory. For each element the daily budget is:
$$\text{Consumed} = \text{Assimilated} + \text{Egested}$$ $$\text{Assimilated} = \text{Growth} + \text{Excreted}$$
Assimilation efficiencies for N and P are species- and prey-specific and can differ from those used for energy.
No return value; this page documents the nutrient regeneration functions module. See individual function documentation for return values.
Sterner, R.W. and Elser, J.J. (2002). Ecological Stoichiometry: The Biology of Elements from Molecules to the Biosphere. Princeton University Press, Princeton, NJ.
Deslauriers, D., Chipps, S.R., Breck, J.E., Rice, J.A. and Madenjian, C.P. (2017). Fish Bioenergetics 4.0: An R-based modeling application. Fisheries, 42(11), 586–596. tools:::Rd_expr_doi("10.1080/03632415.2017.1377558")