Plotting method for Bioenergetic objects to validate setup before simulation.
Usage
# S3 method for class 'Bioenergetic'
plot(x, type = "dashboard", save_plot = NULL, ...)Plotting method for Bioenergetic objects to validate setup before simulation.
# S3 method for class 'Bioenergetic'
plot(x, type = "dashboard", save_plot = NULL, ...)