Learn R Programming

fb4package (version 2.0.0)

process_bioenergetic_data: Process Bioenergetic object temporal data for simulation

Description

Version that processes all temporal data required for FB4 simulation. Includes better error handling and additional data types.

Usage

process_bioenergetic_data(bio_obj, first_day, last_day)

Value

A named list with ten elements containing the temporal arrays interpolated to each simulation day: temperature (numeric vector, °C), diet_proportions (numeric matrix, rows = days, columns = prey), prey_energies (numeric matrix, J/g), prey_indigestible

(numeric matrix, fractions), reproduction (numeric vector, fractions), duration (integer, number of days), prey_names

(character vector), first_day, last_day, and

target_days (integer sequence of simulated days).

Arguments

bio_obj

Bioenergetic object (must be pre-validated)

first_day

First simulation day

last_day

Last simulation day

Examples

Run this code
# \donttest{
# Requires a fully-configured Bioenergetic object; see ?Bioenergetic
# bio <- Bioenergetic(...)
# temporal <- process_bioenergetic_data(bio, first_day = 1, last_day = 365)
# }

Run the code above in your browser using DataLab