Learn R Programming

fb4package (version 2.0.0)

process_predator_params: Process predator energy density parameters

Description

Process predator energy density parameters

Usage

process_predator_params(predator_params, n_days = NULL)

Value

A list containing all elements of predator_params. For PREDEDEQ 1, an ED_data numeric vector of length

n_days + 1 is added (or validated if already present). For PREDEDEQ 2 and 3 the list is returned after validation with no additional derived values.

Arguments

predator_params

Raw predator parameters

n_days

Integer. Number of simulation days, used to build the energy density vector from `ED_ini`/`ED_end` when PREDEDEQ = 1. If `NULL` the vector is built lazily when the simulation starts.

Examples

Run this code
process_predator_params(list(PREDEDEQ = 3, Alpha1 = 4800, Beta1 = 0.1))

Run the code above in your browser using DataLab