Skip to contents

Prints the compact print.fb4_result output followed by a detailed section with execution metadata (backend, version, timing) and method-specific diagnostics: optimisation tolerances for traditional methods, statistical details and profile-likelihood availability for MLE, success rate and percentiles for bootstrap, and individual/population parameter distributions for hierarchical fits. Daily output column availability is reported at the end.

Usage

# S3 method for class 'fb4_result'
summary(object, ...)

Arguments

object

fb4_result object

...

Additional arguments (not used)

Value

Invisibly returns the input object

Examples

# \donttest{
data(fish4_parameters)
sp   <- fish4_parameters[["Oncorhynchus tshawytscha"]]$life_stages$adult
info <- fish4_parameters[["Oncorhynchus tshawytscha"]]$species_info
bio  <- Bioenergetic(
  species_params     = sp,
  species_info       = info,
  environmental_data = list(
    temperature = data.frame(Day = 1:30, Temperature = rep(12, 30))
  ),
  diet_data = list(
    proportions = data.frame(Day = 1:30, Prey1 = 1.0),
    energies    = data.frame(Day = 1:30, Prey1 = 5000),
    prey_names  = "Prey1"
  ),
  simulation_settings = list(initial_weight = 100, duration = 30)
)
#> Bioenergetic object created for: Oncorhynchus tshawytscha
bio$species_params$predator$ED_ini <- 5000
bio$species_params$predator$ED_end <- 5500
result <- run_fb4(bio, strategy = "direct", p_value = 0.5, verbose = FALSE)
#> Validation warnings:
#> Missing optional parameters (will be calculated): CG1, CG2
#> Object is ready for simulation
#> Validation warnings:
#> Missing optional parameters (will be calculated): CG1, CG2
#> Object is ready for simulation
#> Processing species parameters...
#> Processing temporal data...
#> No indigestible fraction data provided, using default 0% for all prey (FB4 default)
#> Processing simulation settings...
#> Simulation data preparation complete. Ready for simulation.
summary(result)
#> FB4 Simulation Results
#> =========================
#> Species: Oncorhynchus tshawytscha
#> Method: Direct Execution
#> Duration: 30 days
#> 
#> RESULTS:
#>   Initial weight: 100 g
#>   Final weight: 134.09 g
#>   Growth: 34.1%
#>   Total consumption: 132.53 g
#>   P_value: 0.5
#> 
#> FITTING: [OK] Successful
#> 
#> ----------------------------------------
#> DETAILED INFORMATION
#> ----------------------------------------
#> EXECUTION:
#>   Backend: r
#>   Version: 2.0.0
#>   Execution time: 0.06 seconds
#>   Timestamp: 2026-06-10 23:20:49
#> 
#> OUTPUT DATA:
#>   Daily values: 30 days
#>   Variables: Weight, Temperature
# }