View source: R/11.3-data-validators.R
| validate_data_consistency | R Documentation |
Checks cross-component consistency within processed simulation data.
validate_data_consistency(simulation_data, n_prey_temporal)
simulation_data |
Complete simulation data |
n_prey_temporal |
Number of prey species in temporal data |
Invisibly returns TRUE if all cross-component consistency
checks pass. Throws an error with a descriptive message when optional
contaminant or nutrient concentration matrices are present but their
number of columns does not match the number of prey species
(n_prey_temporal).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.