Checks cross-component consistency within processed simulation data.
validate_data_consistency(simulation_data, n_prey_temporal)Invisibly returns TRUE if all cross-component consistency
checks pass. Throws an error with a descriptive message when optional
contaminant or nutrient concentration matrices are present but their
number of columns does not match the number of prey species
(n_prey_temporal).
Complete simulation data
Number of prey species in temporal data